summaryrefslogtreecommitdiffstats
path: root/drivers/char/joystick/joy-analog.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/char/joystick/joy-analog.h')
-rw-r--r--drivers/char/joystick/joy-analog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/char/joystick/joy-analog.h b/drivers/char/joystick/joy-analog.h
index 06c0079a4..84479fcd1 100644
--- a/drivers/char/joystick/joy-analog.h
+++ b/drivers/char/joystick/joy-analog.h
@@ -26,7 +26,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -238,7 +238,7 @@ static int __init js_an_probe_devs(struct js_an_info *info, int exist, int mask0
break;
default:
printk(KERN_WARNING "joy-analog: Unknown joystick device detected "
- "(data=%#x), contact <vojtech@ucw.cz>\n", exist);
+ "(data=%#x), contact <vojtech@suse.cz>\n", exist);
return -1;
}
}
@@ -26,7 +26,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/